@@ -1152,7 +1152,7 @@ class Device:
         else:
             text = 'offline'
 
-        self.ui.offline_overlay.label.setText(text)
+        self.ui.offline_overlay.ui.label.setText(text)
         self.ui.offline_overlay.setVisible(len(text) > 0)
         self.ui.offline_overlay.setStyleSheet(style)
 
@@ -1201,7 +1201,7 @@ class Device:
         if present:
             text = ''
 
-        self.ui.connection_monitor_overlay.label.setText(text)
+        self.ui.connection_monitor_overlay.ui.label.setText(text)
         self.ui.connection_monitor_overlay.setVisible(len(text) > 0)
 
         if self.nvs is not None:
